Learn R Programming

irregulAR1 (version 1.0.0)

band1_backsolve: Backsolve with band 1 upper Cholesky.

Description

Backsolve with band 1 upper Cholesky.

Usage

band1_backsolve(U, z)

Arguments

U

An upper triangular square matrix with non-zero entries only on the main diagonal and the first superdiagonal.

z

A vector with as many elements as the number of rows of U.

Value

A vector.

Examples

Run this code
# NOT RUN {
Q <- ar1_prec_irregular(c(1, 3:4, 6), 0.5, 1)
U <- chol_tridiag_upper(Q)
z <- rnorm(nrow(U))
band1_backsolve(U, z)
# }

Run the code above in your browser using DataLab