Learn R Programming

irregulAR1 (version 1.0.0)

band1_backsolve_mat: Backward substitution with band 1 lower Cholesky triangle and tridiagonal RHS.

Description

Backward substitution with band 1 lower Cholesky triangle and tridiagonal matrix on the right hand side.

Usage

band1_backsolve_mat(L, Q)

Arguments

L

A lower triangular square matrix with non-zero entries only on the main diagonal and the first subdiagonal.

Q

A tridiagonal matrix with the same dimensions as L.

Value

A matrix.