Learn R Programming

irregulAR1 (version 1.0.0)

band1_backsolve_vec: Backsolve with band 1 upper Cholesky.

Description

Backsolve with band 1 upper Cholesky.

Usage

band1_backsolve_vec(U, z)

Arguments

U

An upper triangular square matrix with non-zero entries only on the main diagonal and the first superdiagonal.

z

A vector with as many elements as the number of rows of U.

Value

A vector.