ar1_prec_irregular: Precision matrix for a stationary Gaussian AR(1) process, observed at
irregularly spaced time points.
Description
Creates the precision (inverse covariance) matrix of an AR(1) process with
parameters rho and sigma, observed at the time points in the
vector times. The process is assumed to be in stationarity and to
have Gaussian errors.
Usage
ar1_prec_irregular(times, rho, sigma)
Arguments
times
An vector of positive integers, preferably ordered.
rho
A real number strictly less than 1 in absolute value.