powered by
Simulate from a stationary Gaussian AR(1) process at n consecutive time points.
n
ar1_sim_consecutive(n, rho, sigma, mu = 0)
The number of timepoints to simulate for.
A real number strictly less than 1 in absolute value.
A positive real number.
A vector of expected values with length n, or a scalar (default equal to 0).
A vector of length n with the process values.
# NOT RUN { n <- 10 rho <- 0.5 sigma <- 1 mu <- 1:10 ar1_sim_consecutive(n, rho, sigma) ar1_sim_consecutive(n, rho, sigma, mu) # }
Run the code above in your browser using DataLab