powered by
Backsolve with band 1 upper Cholesky.
band1_backsolve(U, z)
An upper triangular square matrix with non-zero entries only on the main diagonal and the first superdiagonal.
A vector with as many elements as the number of rows of U.
A vector.
# NOT RUN { Q <- ar1_prec_irregular(c(1, 3:4, 6), 0.5, 1) U <- chol_tridiag_upper(Q) z <- rnorm(nrow(U)) band1_backsolve(U, z) # }
Run the code above in your browser using DataLab