chol_tridiag_upper: Upper Cholesky decomposition of a tridiagonal matrix.
Description
Creates the lower Cholesky decomposition of a tridiagonal matrix. The
decomposition will be a sparse lower triangular matrix with non-zero
elements only on the main diagonal and the diagonal below it.
Usage
chol_tridiag_upper(Q)
Arguments
Q
A square tridiagonal matrix.
Value
A sparse square matrix with the same size as the input matrix.