powered by
Creates the derivate of the upper Cholesky triangle of the precision matrix of an AR(1) process with respect to the parameter rho.
rho
dprecchol_drho(U, dQ)
The upper Cholesky triangle of the precision matrix Q of the AR(1) process.
Q
The derivative of the precision matrix Q with respect to the correlation parameter rho.
A band 1 upper triangular matrix of the same dimensions as U.
U
# NOT RUN { library(Matrix) t <- c(1, 3:4, 6, 8) r <- 0.5 s <- 1 U <- ar1_prec_chol_irregular(t, r, s) dQ <- dprec_drho(t, r, s) (dU <- dprecchol_drho(U, dQ)) # }
Run the code above in your browser using DataLab